@@ -51,7 +51,7 @@
 #endif
 
 
-#define json_int_t int64_t
+#define json_int_t long long
 #define json_strtoint strtoll
 #define JSON_INTEGER_FORMAT "lld"
 
